@@ -109,6 +109,8 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     :raises pyilt2.queryError: if the database returns an Error on a query
     """
 
+    print("tem que ser")
+
     proplistUrl = 'https://ilthermo.boulder.nist.gov/ILT2/ilprpls'
 
     r = requests.get(proplistUrl)
@@ -122,6 +124,9 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
         pcls['name'] = map(str.strip, pcls['name'])
         prpNames += pcls['name']
         prpKeys += pcls['key']
+    
+    print("aqui")
+
     prop2key = dict(zip(prpNames, prpKeys))
 
     #JOAO
@@ -143,8 +148,8 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     #JOAO
     print("params=",params)
     #JOAO
-    r = requests.get(searchUrl, params=params)
-    resDict = r.json()
+    r1 = requests.get(searchUrl, params=params)
+    resDict = r1.json()
     if len(resDict['errors']) > 0:
         e = " *** ".join(resDict['errors'])
         #JOAO
